<template>
	<view class="datum_index">
		<view class="datum_headers">
			<u--input placeholder="请输入姓名" width="80%" v-model="search.realName"></u--input>
			<view style="width:60px;">
				<u-button type="primary" color="#1977FF" text="查询" @click="searchStaffList"></u-button>
			</view>
		</view>
		<view class="datum_main">
			<scroll-view
				scroll-y="true"
				class="datum_index_scroll"
				:scroll-top="scrollTop" 
				refresher-enabled="true" 
				refresher-background="#EAEAEA"
				:refresher-triggered="triggered" 
				@refresherpulling="refresherrefresh"
				@scrolltolower="scrolltoLower">
				<view class="staff_main_list" v-for="(item,index) in staffLists" :key="index">
					<view class="staff_headers">
						<view class="staff_headers_titles">{{item.jobNum}}-{{item.realName}}</view>
						<view class="staff_headers_btns" @click="tabDetails(item.userId)">详情<u-icon name="arrow-right" color="#1977FF"></u-icon></view>
					</view>
					<view class="staff_contents">
						<view class="staff_contents_items">
							<view class="staff_contents_text">性别：</view>
							<view class="staff_contents_data">{{item.sexStr}}</view>
						</view>
						<view class="staff_contents_items">
							<view class="staff_contents_text">电话：</view>
							<view class="staff_contents_data">{{item.phone}}</view>
						</view>
						<view class="staff_contents_items">
							<view class="staff_contents_text">班组：</view>
							<view class="staff_contents_data">{{item.groupNames===null?'':item.groupNames}}</view>
						</view>
					</view>
				</view>
				<u-loadmore :status="status" :icon-type="iconType" :load-text="loadText" />
			</scroll-view>
		</view>
	</view>
</template>

<script>
	import { throttle } from '../../plugins/public.js';
	export default{
		data(){
			return{
				search:{},//查询条件
				staffLists:[
				],//员工档案列表
				pageNum: 1,
				pageSize: 10,
				loadPage: 0,
				scrollTop: 0,
				triggered: true,
				status: 'loading',
				loadText: {
					loading: '努力加载中',
					nomore: '没有更多数据了'
				},
			}
		},
		onLoad() {
			this.searchStaffList()
		},
		methods:{
			//跳转详情
			tabDetails(val){
				uni.navigateTo({
					url: `./staffDetails?userId=${val}`
				})
			},
			//查询列表
			searchStaffList(){
				this.triggered = true;
				this.staffLists = [];
				let params = Object.assign({},this.search,{
					userType:2,
					pageNum: this.pageNum,
					pageSize:this.pageSize,
				})
				this.$api.reboSystem.getStaffLists(params).then(res=>{
					if(res.statusMsg === 'ok'){
						this.staffLists = res.data.list
						this.loadPage = res.data.pages;
						this.triggered = false;
						this.status = 'nomore';
					}else{
						uni.$u.toast(res.statusMsg);
					}
				}).catch((err) => {
					uni.$u.toast('请检查网络服务或联系管理员！')
				})
			},
			//自定义下拉刷新
			refresherrefresh: throttle(function() {
				this.status = 'loading';
				this.pageNum = 1;
				this.searchStaffList();
				uni.$u.toast('刷新成功');
			}, 500),
			//触底刷新
			scrolltoLower: throttle(function() {
				this.status = 'loading';
				if(this.pageNum >= this.loadPage) {
					setTimeout(() => {
						this.status = 'nomore'
						uni.$u.toast('没有更多数据了');
					},1000)
					return
				} else {
					this.pageNum+=1
					let params = Object.assign({},this.search,{
						userType:2,
						pageNum: this.pageNum,
						pageSize:this.pageSize,
					})
					this.$api.reboSystem.getStaffLists(params).then(res=>{
						if(res.statusMsg === 'ok'){
							this.staffLists.push(...res.data.list)
							this.loadPage = res.data.pages;
							this.triggered = false;
							this.status = 'nomore';
						}else{
							uni.$u.toast(res.statusMsg);
						}
					}).catch((err) => {
						uni.$u.toast('请检查网络服务或联系管理员！')
					})
				}
			}, 1500),
		}
	}
</script>

<style scoped lang="scss">
	.datum_index{
		background-color: #F6F6F6;
		height: 100vh;
		padding: 10px 15px;
		overflow: hidden;
		
		.datum_headers{
			padding: 5px 10px;
			height: 10vh;
			display: flex;
			align-items: center;
			margin-bottom: 15px;
			background-color: #FFFFFF;
			border-radius: 6px;
			
		}
		.datum_main{
			height: calc(100vh - 85px);
			.datum_index_scroll{
				height: 90%;
				
				.staff_main_list{
					margin-bottom: 15px;
					border-radius: 6px;
					background-color: #FFFFFF;
					
					.staff_headers{
						line-height: 45px;
						border-bottom: 1px solid #EAEAEA;
						display: flex;
						justify-content: space-between;
						align-items: center;
						flex-direction: row;
						.staff_headers_titles{
							padding-left: 45px;
							color: #333333;
							font-size: 17px;
							position: relative;
							&::before{
								position: absolute;
								content: "";
								top: 10px;
								left: 10px;
								width: 50px;
								height: 50px;
								background: url('../../static/staff_icon.png') no-repeat;
							}
						}
						.staff_headers_btns{
							padding-right: 10px;
							font-size: 17px;
							color: #1977FF;
							display: flex;
						}
					}
					.staff_contents{
						padding: 10px 0px 10px 10px;
						.staff_contents_items{
							display: flex;
							line-height: 30px;
							.staff_contents_text{
								font-size: 15px;
								color: #999999;
							}
							.staff_contents_data{
								color: #333333;
								font-size: 15px;
							}
						}
					}
				}
			}
		}
	}
	::v-deep .u-border{
		border-top-right-radius: 0px!important;
		border-bottom-right-radius: 0px!important;
		border-color: #1977FF!important;
		padding-top: 5px!important;
		padding-bottom: 9px!important;
	}
	::v-deep .u-button--square{
		border-top-left-radius: 0px!important;
		border-bottom-left-radius: 0px!important;
	}
</style>
<style scoped>
	.icon_style /deep/.u-icon__icon{
		top: 17px!important;
	}
</style>